@@ -10,35 +10,36 @@ from subclean.core.line import Line
 from subclean.core.section import Section, SrtSection
 from subclean.core.section.timing import SrtSectionTiming
 
-ENCODINGS = [
-    "utf-8-sig",
-    "iso-8859-1",
-]
+
+class Encoding(Enum):
+    UTF_8_SIG = "utf-8-sig"
+    ISO_8859_1 = "iso-8859-1"
+    NONE = None
 
 
 class Subtitle:
-    def __init__(self, filepath: str):
-        self.filepath: str = filepath
-        self.encoding: str | None = self.load()
+    def __init__(self, filepath: Path):
+        self.filepath: Path = filepath
+        self.encoding: Encoding = self.load()
         self.file: list[str]
         self.sections: list[Section] = []
         self.parse()
 
-    def load(self) -> str | None:
-        for e in ENCODINGS:
+    def load(self) -> Encoding:
+        for e in Encoding:
             try:
-                with open(self.filepath, encoding=e) as f:
-                    f.readlines()
+                with open(self.filepath, encoding=e.value) as f:
+                    f.read()
                     f.seek(0)
                     logger.debug("Found suitable encoding {}", e)
                     return e
             except UnicodeDecodeError:
                 logger.warning("UnicodeDecodeError for encoding {}", e)
         logger.error("Failed to load file. Couldn't find suitable encoding.")
-        return None
+        return Encoding.NONE
 
     def parse(self):
-        pass
+        raise NotImplementedError
 
     def add_section(self, section: Section):
         self.sections.append(section)
@@ -50,12 +51,18 @@ class Subtitle:
         for section in self.sections:
             print(section)
 
-    def save(self, output_filepath: str | None = None):
-        pass
+    def read(self):
+        with open(self.filepath, encoding=self.encoding.value) as f:
+            for line in f:
+                yield line.strip()
+        yield ""  # append empty new line
+
+    def save(self, path: Path | None = None):
+        raise NotImplementedError
 
 
 class SrtSubtitle(Subtitle):
-    def __init__(self, filepath: str):
+    def __init__(self, filepath: Path):
         super().__init__(filepath)
 
     @staticmethod
@@ -64,39 +71,28 @@ class SrtSubtitle(Subtitle):
         return SrtSectionTiming(start_time, end_time)
 
     def parse(self):
-        with open(self.filepath, encoding=self.encoding) as f:
-            lines: list[str] = list(line.strip() for line in f) + [""]
-
-        for line in lines:
+        for line in self.read():
             # empty line (end of section) or index number (begin of section)
             if not line or line.isdigit():
                 continue
             # timing
             elif " --> " in line:
                 timing = self.__parse_timing(line)
-                section = SrtSection(
-                    timing, lines=[]
-                )  #  TODO why is it not working without explicitely passing lines=[]
+                section = SrtSection(timing)
                 self.sections.append(section)
             # content
             else:
                 self.sections[-1].add_line(Line(line))
 
-    def save(self, output_filepath: str | None = None):
-        if output_filepath is None:
-            p = Path(self.filepath)
-            output_filepath = f"{p.stem}_clean{p.suffix}"
-        logger.info("Saving subtitle {}", output_filepath)
-        with open(output_filepath, "w") as out_f:
+    def save(self, path: Path | None = None):
+        if path is None:
+            path = self.filepath.with_stem(self.filepath.stem + "_clean")
+        logger.info("Saving subtitle {}", path)
+        with open(path, "w") as out_f:
             for index, section in enumerate(self.sections, start=1):
                 out_f.write(f"{index}\n{section}\n")
 
 
-class FakeSubtitle(Subtitle):
-    def __init__(self):
-        pass
-
-
 class SubtitleFormat(Enum):
     def __init__(self, ext, handler):
         self.ext: str = ext
